##
# Copyright 2009-2012 Stijn Deweirdt, Dries Verdegem, Kenneth Hoste, Pieter De Baets, Jens Timmerman
#
# This file is part of EasyBuild,
# originally created by the HPC team of the University of Ghent (http://ugent.be/hpc).
#
# http://github.com/hpcugent/easybuild
#
# EasyBuild is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation v2.
#
# EasyBuild is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with EasyBuild.  If not, see <http://www.gnu.org/licenses/>.
##
import glob
import os
import shutil
from easybuild.easyblocks.g.g2lib import G2lib

class G2clib(G2lib):
    """Support for building g2clib GRIB2 C library."""

    def make_install(self):
        """Install by copying library and header files to install directory."""

        try:
            # copy library
            targetdir = os.path.join(self.installdir,"lib")
            os.mkdir(targetdir)
            fn = "libgrib2c.a"
            shutil.copyfile(os.path.join(self.getcfg('startfrom'),fn),
                            os.path.join(targetdir,fn))

            # copy header files
            targetdir = os.path.join(self.installdir,"include")
            os.mkdir(targetdir)
            for fn in glob.glob('*.h'):
                shutil.copyfile(os.path.join(self.getcfg('startfrom'),fn),
                                os.path.join(targetdir,fn))

        except OSError, err:
            self.log.error("Failed to copy files to install dir: %s" % err)

    def sanitycheck(self):
        """Custom sanity check for g2clib."""

        if not self.getcfg('sanityCheckPaths'):
            self.setcfg('sanityCheckPaths',{'files':["lib/libgrib2c.a"],
                                            'dirs':["include"]
                                            })

        G2lib.sanitycheck(self)